@@ -36,7 +36,13 @@ class Storage(driver.Base):
         object_instance = self._jss.bucket(self._bucket).object(path)
         
         return object_instance.generate_url("GET")
-
+    
+    def get_json(self, path):
+        try:
+            return json.loads(self.get_unicode(path))
+        except:
+            return []
+            
     @lru.get
     def get_content(self, path):
         print "get_content path:"+path
